﻿--[[
Name: Prat_ArmoryLink
Revision: $Revision: 14 $
Author(s):  Danny (dekimsey@gmail.com)
Website: http://files.wowace.com/Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#ArmoryLink
Subversion: http://svn.wowace.com/wowace/trunk/Prat/
Discussions: http://groups.google.com/group/wow-prat
Issues and feature requests: http://code.google.com/p/prat/issues/list
Description: Adds a popup winodw that contains a direct url to the WoW Armory page.(default=off).
Dependencies: Prat
]]

Prat:AddModuleToLoad(function() 

-- set prat module name
local PRAT_MODULE = Prat:RequestModuleName("ArmoryLink")

if PRAT_MODULE == nil then 
    return 
end

-- define localized strings
local L = Prat:GetLocalizer({})
local R = {
    ["us"] = "http://us.wowarmory.com/character-sheet.xml?r=%s&n=%s",
    ["eu"] = "http://eu.wowarmory.com/character-sheet.xml?r=%s&n=%s",
    ["ko"] = "http://ko.wowarmory.com/character-sheet.xml?r=%s&n=%s",
    ["tw"] = "http://tw.wowarmory.com/character-sheet.xml?r=%s&n=%s",
    [""]   = "Unknown Server<%s> Character<%s>.",    
}
L:AddLocale("enUS", {
	["ArmoryLink"] = true,
	["ArmoryDesc"] = "Adds a popup window that contains a direct url to the WoW Armory page.",
    ["WoW Armory link for: %s."] = true,
	["Armory URL"] = true,
	["Set the Armory URL template to be used."] = true,
	["<armory url> (must have two '%s', for realm and character name respectively)"] = true,
    }
)

local module = Prat:NewModule(PRAT_MODULE, "AceHook-3.0")

Prat:SetModuleDefaults(module.name, {
	profile = {
		on	    = true,
	},
    realm = {
        url = nil,
    }
} )

Prat:SetModuleInit(module, 
	function(self) 
        self:resetURL()
        self:StaticPopupArmoryLink()
        return
    end
)
function module:resetURL()
        local realm = self:getRealm()
        if realm == nil then
            realm = ""
        end
        self.db.profile.url = R[realm]
end
function module:UnitPopup_ShowMenu(dropdownMenu, which, unit, name, userData, ...)
	for i=1, UIDROPDOWNMENU_MAXBUTTONS do
		button = getglobal("DropDownList"..UIDROPDOWNMENU_MENU_LEVEL.."Button"..i);

		-- Patch our handler function back in
		if  button.value == "ARMORY_LINK" then
		    button.func = UnitPopupButtons["ARMORY_LINK"].func
		end
	end
end
function module:OnModuleEnable()
    self:SecureHook("UnitPopup_ShowMenu")
    Prat:RegisterDropdownButton("ARMORY_LINK")
    UnitPopupButtons['ARMORY_LINK'] = { 
        text = "Armory Link", 
        dist = 0, 
        func = function() module:UnitPopup_ArmoryLinkOnClick() end , 
        arg1 = "", 
        arg2 = ""
    }
    local popupList = { 
        'PARTY',        -- party frame.
        'FRIEND',       -- friend frame
        'SELF',         -- ?
        'PLAYER',       -- ?
        'RAID',         -- raid frames
        'RAID_PLAYER',  -- player's raid frame?
        'TEAM'          -- arena team
    }
    for key,val in pairs(popupList) do
        tinsert(UnitPopupMenus[val], #UnitPopupMenus[val]-1,'ARMORY_LINK')
    end
end

function module:UnitPopup_ArmoryLinkOnClick()
	local dropdownFrame = UIDROPDOWNMENU_INIT_MENU
    local name      = dropdownFrame.name
    local server    = dropdownFrame.server
    self:StaticPopupArmoryLink(name,server)
end

Prat:SetModuleOptions(module, {
    	name	= L["ArmoryLink"],
		desc	= L["ArmoryDesc"],
		type	= "group",
		args    = {
            url = {
				name	= L["Armory URL"],
				desc	= L["Set the Armory URL template to be used."],
				type	= "input",
				usage	= L["<armory url> (must have two '%s', for realm and character name respectively)"],
				set	    = function(info, q) info.handler.db.profile.url = q     end,
				get	    = function(info)    return info.handler.db.profile.url  end,
            },
        },
    }
)

function module:getRealm()
    return GetCVar("realmList"):match("^(%w+)%.")
end

function module:getArmoryLink(name,server)
    if name == nil or name == '' then
        return
    end
    if server == nil or server == "" then
        server = GetRealmName()
    end
    return format(self.db.profile.url, module:url_encode(server), module:url_encode(name))
end

function module:url_encode(str)
  if (str) then
    --str = string.gsub (str, "\n", "\r\n")
    str = string.gsub (str, "([^%w ])",
        function (c) return string.format ("%%%02X", string.byte(c)) end)
    str = string.gsub (str, " ", "+")
  end
  return str	
end
-- define a popup to get the main name
function module:StaticPopupArmoryLink(name, server)
    StaticPopupDialogs["MENUITEM_ARMORYLINK"] = StaticPopupDialogs["MENUITEM_ARMORYLINK"] or {
        text = L["WoW Armory link for: %s."],
        link = '',
        button2 = ACCEPT,
        hasEditBox = 1,
        hasWideEditBox = 1,

        OnShow = function()
            this:SetWidth(420)
            local menuname = this:GetName()
            local editBox = getglobal(menuname.."WideEditBox");
            editBox:SetText(StaticPopupDialogs["MENUITEM_ARMORYLINK"].link);
            editBox:SetFocus();
            editBox:HighlightText(0);

            local button = getglobal(menuname.."Button2");
            button:ClearAllPoints();
            button:SetWidth(200);
            button:SetPoint("CENTER", editBox, "CENTER", 0, -30);
        end,

        OnHide = function() end,
        OnAccept = function() end,
        OnCancel = function() end,
        EditBoxOnEscapePressed = function() this:GetParent():Hide(); end,
        timeout = 0,
        whileDead = 1,
        hideOnEscape = 1
    };
    local link = self:getArmoryLink(name, server)
    if link == nil then
        link = '<error>'
    end
    StaticPopupDialogs["MENUITEM_ARMORYLINK"].link = link
    if name then
        StaticPopup_Show("MENUITEM_ARMORYLINK", name)
    end
end

end ) -- Prat:AddModuleToLoad
